/************************************************************************************
gpsinformationprocessingirs
Copyright (c) 2010, International Rescue System Institute
All rights reserved.

Contact us if you use this software for sell.
If you use this software not for sell, you can use this software under BSD license.
See the files LICENSE.TXT and LICENSE-BSD.TXT for more details.                     
************************************************************************************/

//***************************************************************************************//
//* GpsInformationProcessing.cpp					     2009.12.14 *//
//*											*//
//* GPS Information Processing RTMプログラム [Ver.0.1.0]				*//
//*											*//
//* コンフィギュレーション								*//
//*	01_gui		: GUI動作							*//
//*			  [off, on]							*//
//*	02_guiaddress	: GUIプログラムアドレス						*//
//*	03_ip		: IPアドレス							*//
//*	04_sendport	: 送信ポート番号						*//
//*	05_receiveport	: 受信ポート番号						*//
//***************************************************************************************//


// -*- C++ -*-
/*!
 * @file  GpsInformationProcessing.cpp
 * @brief Information Processing for LEGACY-E+
 * $Date$
 *
 * $Id$
 */

#include "GpsInformationProcessing.h"


//-- [変数宣言] ---------------------------------------------------------------------------------//
int wait_flag = 1;											// フラグ格納変数 [読み込み用]
//-----------------------------------------------------------------------------------------------//


// Module specification
// <rtc-template block="module_spec">
static const char* gpsinformationprocessing_spec[] =
  {
    "implementation_id", "GpsInformationProcessing",
    "type_name",         "GpsInformationProcessing",
    "description",       "Information Processing for LEGACY-E+",
    "version",           "0.1.0",
    "vendor",            "IRS",
    "category",          "Position",
    "activity_type",     "DataFlowComponent",
    "max_instance",      "1",
    "language",          "C++",
    "lang_type",         "compile",
    // Configuration variables
    "conf.default.01_gui", "on",
    "conf.default.02_guiaddress", "../gui/gpsinformationprocessing",
    "conf.default.03_ip", "127.0.0.1",
    "conf.default.04_sendport", "10002",
    "conf.default.05_receiveport", "10001",

    ""
  };
// </rtc-template>

GpsInformationProcessing::GpsInformationProcessing(RTC::Manager* manager)
  : RTC::DataFlowComponentBase(manager),
    // <rtc-template block="initializer">
    m_LegacyDataIn("LegacyData", m_LegacyData),
    m_Jgd2000PositionOut("Jgd2000Position", m_Jgd2000Position),
    m_GpsDataOut("GpsData", m_GpsData),
    
    // </rtc-template>
	dummy(0)
{
  // Registration: InPort/OutPort/Service
  // <rtc-template block="registration">
  // Set InPort buffers
  registerInPort("LegacyData", m_LegacyDataIn);
  
  // Set OutPort buffer
  registerOutPort("Jgd2000Position", m_Jgd2000PositionOut);
  registerOutPort("GpsData", m_GpsDataOut);
  
  // Set service provider to Ports
  
  // Set service consumers to Ports
  
  // Set CORBA Service Ports
  
  // </rtc-template>

}

GpsInformationProcessing::~GpsInformationProcessing()
{
}


RTC::ReturnCode_t GpsInformationProcessing::onInitialize()
{
	// <rtc-template block="bind_config">
	// Bind variables and configuration variable
	bindParameter("01_gui", m_01_gui, "on");
	bindParameter("02_guiaddress", m_02_guiaddress, "../gui/gpsinformationprocessing");
	bindParameter("03_ip", m_03_ip, "127.0.0.1");
	bindParameter("04_sendport", m_04_sendport, "10002");
	bindParameter("05_receiveport", m_05_receiveport, "10001");
  
	// </rtc-template>

	return RTC::RTC_OK;										// 戻り値 [正常終了]

}

/*
RTC::ReturnCode_t GpsInformationProcessing::onFinalize()
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t GpsInformationProcessing::onStartup(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t GpsInformationProcessing::onShutdown(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

RTC::ReturnCode_t GpsInformationProcessing::onActivated(RTC::UniqueId ec_id)
{


	//-- [初期化] ---------------------------------------------------------------------------//

	wait_flag = 1;											// フラグ初期化 [読み取り用]
	mode      = 0;											// メッセージモード初期化
	sec       = 0;											// タイムスタンプ初期化 [sec]
	nsec      = 0;											// タイムスタンプ初期化 [nsec]
	for(i = 0; i < 3; i++) send_value[i] = 0.0;							// 送信元データ初期化

	//---------------------------------------------------------------------------------------//


	//-- [メッセージ初期化] -----------------------------------------------------------------//

	for(i = 0; i < 16; i++) strcpy(gga[i], "");							// 初期化 [GGA]
	for(i = 0; i <  9; i++) strcpy(gll[i], "");							// 初期化 [GLL]
	for(i = 0; i < 13; i++) strcpy(gns[i], "");							// 初期化 [GNS]
	for(i = 0; i < 13; i++) strcpy(gp_gns[i], "");							// 初期化 [GNS]
	for(i = 0; i < 13; i++) strcpy(gl_gns[i], "");							// 初期化 [GNS]
	for(i = 0; i < 16; i++) strcpy(gp_grs[i], "");							// 初期化 [GRS]
	for(i = 0; i < 16; i++) strcpy(gl_grs[i], "");							// 初期化 [GRS]
	for(i = 0; i < 19; i++) strcpy(gp_gsa[i], "");							// 初期化 [GSA]
	for(i = 0; i < 19; i++) strcpy(gl_gsa[i], "");							// 初期化 [GSA]
	for(i = 0; i < 10; i++) strcpy(gst[i], "");							// 初期化 [GST]
	for(i = 0; i < 21; i++) strcpy(gp_gsv[0][i], "");						// 初期化 [GSV]
	for(i = 0; i < 21; i++) strcpy(gp_gsv[1][i], "");						// 初期化 [GSV]
	for(i = 0; i < 21; i++) strcpy(gp_gsv[2][i], "");						// 初期化 [GSV]
	for(i = 0; i < 21; i++) strcpy(gl_gsv[0][i], "");						// 初期化 [GSV]
	for(i = 0; i < 21; i++) strcpy(gl_gsv[1][i], "");						// 初期化 [GSV]
	for(i = 0; i < 21; i++) strcpy(gl_gsv[2][i], "");						// 初期化 [GSV]
	for(i = 0; i <  4; i++) strcpy(hdt[i], "");							// 初期化 [HDT]
	for(i = 0; i < 14; i++) strcpy(rmc[i], "");							// 初期化 [RMC]
	for(i = 0; i < 11; i++) strcpy(vtg[i], "");							// 初期化 [VTG]
	for(i = 0; i <  8; i++) strcpy(zda[i], "");							// 初期化 [ZDA]

	//---------------------------------------------------------------------------------------//


	//-- [出力ポート初期化] -----------------------------------------------------------------//

	// Jgd2000Position初期化
	m_Jgd2000Position.tm.sec    = 0;								// 初期化 [sec]
	m_Jgd2000Position.tm.nsec   = 0;								// 初期化 [nsec]
	m_Jgd2000Position.latitude  = 0.0;								// 初期化 [latitude]
	m_Jgd2000Position.longitude = 0.0;								// 初期化 [longitude]

	// GpsData初期化
	m_GpsData.tm.sec                    = 0;							// 初期化 [sec]
	m_GpsData.tm.nsec                   = 0;							// 初期化 [nsec]
	m_GpsData.Jgd2000Position.tm.sec    = 0;							// 初期化 [sec]
	m_GpsData.Jgd2000Position.tm.nsec   = 0;							// 初期化 [nsec]
	m_GpsData.Jgd2000Position.latitude  = 0.0;							// 初期化 [latitude]
	m_GpsData.Jgd2000Position.longitude = 0.0;							// 初期化 [longitude]

	//---------------------------------------------------------------------------------------//


	//-- [コンフィギュレーション読み込み] ---------------------------------------------------//

	strcpy(gui,       m_01_gui.c_str());								// データ格納 [GUI動作]
	strcpy(gui_addr,  m_02_guiaddress.c_str());							// データ格納 [GUIプログラムアドレス]
	strcpy(ip,        m_03_ip.c_str());								// データ格納 [IPアドレス]
	strcpy(send_port, m_04_sendport.c_str());							// データ格納 [送信ポート番号]
	strcpy(recv_port, m_05_receiveport.c_str());							// データ格納 [受信ポート番号]

	//---------------------------------------------------------------------------------------//


	//-- [デバッグconfiguration] ------------------------------------------------------------//

	#ifndef DEBUG_CONFIGURATION									// デバッグ表示開始

	printf("\n[configuration]\n");									// label
	printf("01_gui         = %s\n", gui);								// gui
	printf("02_guiaddress  = %s\n", gui_addr);							// guiaddress
	printf("03_ip          = %s\n", ip);								// ip
	printf("04_sendport    = %s\n", send_port);							// sendport
	printf("05_receiveport = %s\n\n", recv_port);							// receiveport
	fflush(stdout);											// バッファフラッシュ [printf表示用]

	#endif												// デバッグ表示終了

	//---------------------------------------------------------------------------------------//


	//-- [コンフィギュレーションチェック] ---------------------------------------------------//

	// GUI動作チェック
	if(strcmp("off", gui) == 0) gui_flag = 0;							// GUI機能OFF
	else if(strcmp("on", gui) == 0) gui_flag = 1;							// GUI機能ON
	else{

		printf("configuration error:01_gui = %s\n", gui);					// エラーメッセージ
		fflush(stdout);										// バッファフラッシュ [printf表示用]

		return RTC::RTC_ERROR;									// 戻り値 [異常終了]

	}

	//---------------------------------------------------------------------------------------//


	//-- [GUI関連] --------------------------------------------------------------------------//

	if(gui_flag == 1){										// GUI機能ON


		//-- [GUIプログラム起動] --------------------------------------------------------//

		strcpy(command, gui_addr);								// 実行プログラム
		strcat(command, " ");									// 空白
		strcat(command, ip);									// オプション [IPアドレス]
		strcat(command, " ");									// 空白
		strcat(command, recv_port);								// オプション [受信ポート番号]
		strcat(command, " ");									// 空白
		strcat(command, send_port);								// オプション [送信ポート番号]
		strcat(command, " &");									// オプション [バックグランド]
		system(command);									// GUIプログラム起動
		usleep(WAITTIME);									// 待機 WAITTIME [us]

		//-------------------------------------------------------------------------------//


		//-- [UDP通信関連初期化] --------------------------------------------------------//

		memset(send_data, 0, sizeof(send_data));						// 送信データ初期化
		memset(recv_data, 0, sizeof(recv_data));						// 受信データ初期化

		//-------------------------------------------------------------------------------//


		//-- [ソケット作成] -------------------------------------------------------------//
		//-										-//
		//- プロトコル・ファミリ							-//
		//- AF_UNIX, AF_LOCAL	: ローカル通信						-//
		//- AF_INET		: IPv4 インターネットプロトコル				-//
		//- AF_INET6		: IPv6 インターネットプロトコル				-//
		//- AF_IPX		: IPX-NoveIIプロトコル					-//
		//- AF_NETLINK		: カーネルユーザデバイス				-//
		//- AF_X25		: ITU-T X.25/ISO-8208プロトコル				-//
		//- AF_AX25		: アマチュア無線AX.25プロトコル				-//
		//- AF_ATMPVC		: ATMPVC						-//
		//- AF_APPLETALK	: アップルトーク					-//
		//- AF_PACKET		: 低レベルパケットインターフェイス			-//
		//-										-//
		//- 通信方式									-//
		//- SOCK_STREAM		: バイトストリーム	[信頼性有:順序保証有:双方向]	-//
		//- SOCK_DGRAM		: データグラム		[信頼性有:固定最大長]		-//
		//- SOCK_SEQPACKET	: データグラム		[信頼性有:固定最大長:双方向]	-//
		//- SOCK_RAW		: 生ネットワーク					-//
		//- SOCK_RDW		: データグラム		[信頼性有:順序保証無]		-//
		//- SOCK_PACKET		: 廃止							-//
		//-------------------------------------------------------------------------------//

		if((send_sock = socket(AF_INET, SOCK_DGRAM, 0)) < 0){					// ソケット作成 [送信データ用]

			printf("socket error!!\n");							// メッセージ表示
			fflush(stdout);									// バッファフラッシュ [printf表示用]

			return RTC::RTC_ERROR;								// 戻り値 [異常終了]

		}

		if((recv_sock = socket(AF_INET, SOCK_DGRAM, 0)) < 0){					// ソケット作成 [送信データ用]

			printf("socket error!!\n");							// メッセージ表示
			fflush(stdout);									// バッファフラッシュ [printf表示用]

			return RTC::RTC_ERROR;								// 戻り値 [異常終了]

		}

		//-------------------------------------------------------------------------------//


		//-- [アドレス設定] -------------------------------------------------------------//

		send_addr.sin_family      = AF_INET;							// アドレスファミリ
		send_addr.sin_port        = htons(atoi(send_port));					// ポート番号 [バイトオーダ]
		send_addr.sin_addr.s_addr = inet_addr(ip);						// IPアドレス [バイトオーダ]

		recv_addr.sin_family      = AF_INET;							// アドレスファミリ
		recv_addr.sin_port        = htons(atoi(recv_port));					// ポート番号 [バイトオーダ]
		recv_addr.sin_addr.s_addr = inet_addr(ip);						// IPアドレス [バイトオーダ]

		//-------------------------------------------------------------------------------//


		//-- [受信設定] -----------------------------------------------------------------//

		bind(recv_sock, (struct sockaddr *)&recv_addr, sizeof(recv_addr));			// バインド [受信データ]
		addr_size = sizeof(recv_addr);								// アドレス格納構造体サイズ格納

		//-------------------------------------------------------------------------------//


		//-- [シグナルハンドル設定] -----------------------------------------------------//

		saio.sa_handler = signal_handler_IO;							// シグナルハンドル
		sigemptyset(&saio.sa_mask);								// 追加マスクシグナル
		saio.sa_flags = 0;									// 動作詳細設定フラグ
		saio.sa_restorer = NULL;								// オボソリート [= NULL]

		//-------------------------------------------------------------------------------//


		//-- [シグナルアクション調査/変更] ----------------------------------------------//

		sigaction(SIGIO, &saio, NULL);								// シグナルアクション調査/変更

		//-------------------------------------------------------------------------------//


		//-- [非同期通信モード設定] -----------------------------------------------------//

		fcntl(recv_sock, F_SETOWN, getpid());							// シグナル受け取り設定 [プロセス]
		fcntl(recv_sock, F_SETFL, O_NONBLOCK | FASYNC);						// 非同期通信モード設定

		//-------------------------------------------------------------------------------//


	}

	//---------------------------------------------------------------------------------------//


	return RTC::RTC_OK;										// 戻り値 [正常終了]

}

RTC::ReturnCode_t GpsInformationProcessing::onDeactivated(RTC::UniqueId ec_id)
{


	//-- [GUI関連] --------------------------------------------------------------------------//

	if(gui_flag == 1){										// GUI機能ON


		//-- [GUIプログラム終了コマンド送信] --------------------------------------------//

		strcpy(send_data, "quit");								// 送信データ設定

		if(sendto(send_sock, send_data, strlen(send_data), 0,
			(struct sockaddr *)&send_addr, sizeof(send_addr)) < 0){				// データ送信

			printf("send error!!\n");							// メッセージ表示
			fflush(stdout);									// バッファフラッシュ [printf表示用]

			return RTC::RTC_ERROR;								// 戻り値 [異常終了]

		}

		//-------------------------------------------------------------------------------//


		//-- [ソケットディスクリプタクローズ] -------------------------------------------//

		close(send_sock);									// ソケットディスクリプタクローズ
		close(recv_sock);									// ソケットディスクリプタクローズ

		//-------------------------------------------------------------------------------//


	}

	//---------------------------------------------------------------------------------------//


	return RTC::RTC_OK;										// 戻り値 [正常終了]

}

RTC::ReturnCode_t GpsInformationProcessing::onExecute(RTC::UniqueId ec_id)
{


	//-- [データ更新] -----------------------------------------------------------------------//

	if(m_LegacyDataIn.isNew()){									// 更新チェック

		m_LegacyDataIn.read();									// データ読み込み


		//-- [データ格納] ---------------------------------------------------------------//

		sec  = m_LegacyData.tm.sec;								// タイムスタンプ格納 [sec]
		nsec = m_LegacyData.tm.nsec;								// タイムスタンプ格納 [nsec]
		mode = m_LegacyData.mode;								// メッセージモード格納 [mode]


		//-- [GGAメッセージ取得] --------------------------------------------------------//

		if((mode & 0x0001) == 0x0001){

			for(i = 0; i < DATASIZE; i++){

				gga[0][i] = m_LegacyData.gga.field00[i];				// データ格納 [GGA]
				if(gga[0][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gga[1][i] = m_LegacyData.gga.field01[i];				// データ格納 [GGA]
				if(gga[1][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gga[2][i] = m_LegacyData.gga.field02[i];				// データ格納 [GGA]
				if(gga[2][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gga[3][i] = m_LegacyData.gga.field03[i];				// データ格納 [GGA]
				if(gga[3][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gga[4][i] = m_LegacyData.gga.field04[i];				// データ格納 [GGA]
				if(gga[4][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gga[5][i] = m_LegacyData.gga.field05[i];				// データ格納 [GGA]
				if(gga[5][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gga[6][i] = m_LegacyData.gga.field06[i];				// データ格納 [GGA]
				if(gga[6][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gga[7][i] = m_LegacyData.gga.field07[i];				// データ格納 [GGA]
				if(gga[7][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gga[8][i] = m_LegacyData.gga.field08[i];				// データ格納 [GGA]
				if(gga[8][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gga[9][i] = m_LegacyData.gga.field09[i];				// データ格納 [GGA]
				if(gga[9][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gga[10][i] = m_LegacyData.gga.field10[i];				// データ格納 [GGA]
				if(gga[10][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gga[11][i] = m_LegacyData.gga.field11[i];				// データ格納 [GGA]
				if(gga[11][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gga[12][i] = m_LegacyData.gga.field12[i];				// データ格納 [GGA]
				if(gga[12][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gga[13][i] = m_LegacyData.gga.field13[i];				// データ格納 [GGA]
				if(gga[13][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gga[14][i] = m_LegacyData.gga.field14[i];				// データ格納 [GGA]
				if(gga[14][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gga[15][i] = m_LegacyData.gga.field15[i];				// データ格納 [GGA]
				if(gga[15][i] == 0x00) break;						// 終端文字チェック

			}


			//-- [タイムスタンプ処理] -----------------------------------------------//

			gga_sec = (unsigned long)(atof(gga[1]));					// UTC一時格納 [sec]
			gga_sec = (gga_sec / 10000) * 3600 + ((gga_sec % 10000) / 100) * 60
				+ (gga_sec % 100);							// タイムスタンプ格納 [sec]
			gga_nsec = (unsigned long)(fmod(atof(gga[1]), 1) * 1000000000);			// UTC一時格納 [nsec]
			if((gga_nsec % 10) != 0) gga_nsec++;						// 四捨五入処理

			if((gga_sec != 0) || (gga_nsec != 0)){						// 受信チェック

				m_Jgd2000Position.tm.sec = gga_sec;					// タイムスタンプ格納 [sec]
				m_Jgd2000Position.tm.nsec = gga_nsec;					// タイムスタンプ格納 [nsec]
				m_GpsData.tm.sec = gga_sec;						// タイムスタンプ格納 [sec]
				m_GpsData.tm.nsec = gga_nsec;						// タイムスタンプ格納 [nsec]
				m_GpsData.Jgd2000Position.tm.sec = gga_sec;				// タイムスタンプ格納 [sec]
				m_GpsData.Jgd2000Position.tm.nsec = gga_nsec;				// タイムスタンプ格納 [nsec]
				send_value[0] = (double)gga_sec + (double)gga_nsec / 1000000000.0;	// タイムスタンプ格納 [sec]

			}

			//-----------------------------------------------------------------------//


			//-- [緯度・経度処理] ---------------------------------------------------//

			latitude  = 0.0;								// 初期化 [latitude]
			longitude = 0.0;								// 初期化 [longitude]
			m_Jgd2000Position.latitude = latitude;						// 初期化 [latitude]
			m_GpsData.Jgd2000Position.latitude = latitude;					// 初期化 [latitude]
			m_Jgd2000Position.longitude = longitude;					// 初期化 [longitude]
			m_GpsData.Jgd2000Position.longitude = longitude;				// 初期化 [longitude]

			if((gga[3][0] == 'N') || (gga[3][0] == 'S')){					// データチェック

				if(gga[3][0] == 'N') latitude = atof(gga[2]);				// 緯度格納 [latitude]
				else if(gga[3][0] == 'S') latitude = - atof(gga[2]);			// 緯度格納 [latitude]

				latitude = (double)(((long int)latitude) * 100)
					+ fmod(latitude, 1) * 60.0;					// 緯度変換 [DMS]

				m_Jgd2000Position.latitude = latitude;					// 緯度格納 [latitude]
				m_GpsData.Jgd2000Position.latitude = latitude;				// 緯度格納 [latitude]
				send_value[1] = latitude;						// 緯度格納 [latitude]

			}

			if((gga[5][0] == 'E') || (gga[5][0] == 'W')){					// データチェック

				if(gga[5][0] == 'E') longitude = atof(gga[4]);				// 経度格納 [longitude]
				else if(gga[5][0] == 'W') longitude = - atof(gga[4]);			// 経度格納 [longitude]

				longitude = (double)(((long int)longitude) * 100)
					+ fmod(longitude, 1) * 60.0;					// 経度変換 [DMS]

				m_Jgd2000Position.longitude = longitude;				// 経度格納 [longitude]
				m_GpsData.Jgd2000Position.longitude = longitude;			// 経度格納 [longitude]
				send_value[2] = longitude;						// 経度格納 [longitude]

			}

			//-----------------------------------------------------------------------//


			//-- [デバッグgga] ------------------------------------------------------//

			#ifndef DEBUG_GGA								// デバッグ表示開始

			printf("\n[gga      ]\n");							// label
			printf("[gga_sec  ] %ld\n", gga_sec);						// gga_sec
			printf("[gga_nsec ] %ld\n", gga_nsec);						// gga_nsec
			printf("[latitude ] %lf\n", latitude);						// latitude
			printf("[longitude] %lf\n\n", longitude);					// longitude
			fflush(stdout);									// バッファフラッシュ [printf表示用]

			#endif										// デバッグ表示終了

			//-----------------------------------------------------------------------//


		}

		//-------------------------------------------------------------------------------//


		//-- [GLLメッセージ取得] --------------------------------------------------------//

		if((mode & 0x0002) == 0x0002){

			for(i = 0; i < DATASIZE; i++){

				gll[0][i] = m_LegacyData.gll.field00[i];				// データ格納 [GLL]
				if(gll[0][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gll[1][i] = m_LegacyData.gll.field01[i];				// データ格納 [GLL]
				if(gll[1][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gll[2][i] = m_LegacyData.gll.field02[i];				// データ格納 [GLL]
				if(gll[2][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gll[3][i] = m_LegacyData.gll.field03[i];				// データ格納 [GLL]
				if(gll[3][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gll[4][i] = m_LegacyData.gll.field04[i];				// データ格納 [GLL]
				if(gll[4][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gll[5][i] = m_LegacyData.gll.field05[i];				// データ格納 [GLL]
				if(gll[5][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gll[6][i] = m_LegacyData.gll.field06[i];				// データ格納 [GLL]
				if(gll[6][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gll[7][i] = m_LegacyData.gll.field07[i];				// データ格納 [GLL]
				if(gll[7][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gll[8][i] = m_LegacyData.gll.field08[i];				// データ格納 [GLL]
				if(gll[8][i] == 0x00) break;						// 終端文字チェック

			}


			//-- [タイムスタンプ処理] -----------------------------------------------//

			gll_sec = (unsigned long)(atof(gll[5]));					// UTC一時格納 [sec]
			gll_sec = (gll_sec / 10000) * 3600 + ((gll_sec % 10000) / 100) * 60
				+ (gll_sec % 100);							// タイムスタンプ格納 [sec]
			gll_nsec = (unsigned long)(fmod(atof(gll[5]), 1) * 1000000000);			// UTC一時格納 [nsec]
			if((gll_nsec % 10) != 0) gll_nsec++;						// 四捨五入処理

			if((gll_sec != 0) || (gll_nsec != 0)){						// 受信チェック

				m_Jgd2000Position.tm.sec = gll_sec;					// タイムスタンプ格納 [sec]
				m_Jgd2000Position.tm.nsec = gll_nsec;					// タイムスタンプ格納 [nsec]
				m_GpsData.tm.sec = gll_sec;						// タイムスタンプ格納 [sec]
				m_GpsData.tm.nsec = gll_nsec;						// タイムスタンプ格納 [nsec]
				m_GpsData.Jgd2000Position.tm.sec = gll_sec;				// タイムスタンプ格納 [sec]
				m_GpsData.Jgd2000Position.tm.nsec = gll_nsec;				// タイムスタンプ格納 [nsec]
				send_value[0] = (double)gll_sec + (double)gll_nsec / 1000000000.0;	// タイムスタンプ格納 [sec]

			}

			//-----------------------------------------------------------------------//


			//-- [緯度・経度処理] ---------------------------------------------------//

			latitude  = 0.0;								// 初期化 [latitude]
			longitude = 0.0;								// 初期化 [longitude]
			m_Jgd2000Position.latitude = latitude;						// 初期化 [latitude]
			m_GpsData.Jgd2000Position.latitude = latitude;					// 初期化 [latitude]
			m_Jgd2000Position.longitude = longitude;					// 初期化 [longitude]
			m_GpsData.Jgd2000Position.longitude = longitude;				// 初期化 [longitude]

			if((gll[2][0] == 'N') || (gll[2][0] == 'S')){					// データチェック

				if(gll[2][0] == 'N') latitude = atof(gll[1]);				// 緯度格納 [latitude]
				else if(gll[2][0] == 'S') latitude = - atof(gll[1]);			// 緯度格納 [latitude]

				latitude = (double)(((long int)latitude) * 100)
					+ fmod(latitude, 1) * 60.0;					// 緯度変換 [DMS]

				m_Jgd2000Position.latitude = latitude;					// 緯度格納 [latitude]
				m_GpsData.Jgd2000Position.latitude = latitude;				// 緯度格納 [latitude]
				send_value[1] = latitude;						// 緯度格納 [latitude]

			}

			if((gll[4][0] == 'E') || (gll[4][0] == 'W')){					// データチェック

				if(gll[4][0] == 'E') longitude = atof(gll[3]);				// 経度格納 [longitude]
				else if(gll[4][0] == 'W') longitude = - atof(gll[3]);			// 経度格納 [longitude]

				longitude = (double)(((long int)longitude) * 100)
					+ fmod(longitude, 1) * 60.0;					// 経度変換 [DMS]

				m_Jgd2000Position.longitude = longitude;				// 経度格納 [longitude]
				m_GpsData.Jgd2000Position.longitude = longitude;			// 経度格納 [longitude]
				send_value[2] = longitude;						// 経度格納 [longitude]

			}

			//-----------------------------------------------------------------------//


			//-- [デバッグgll] ------------------------------------------------------//

			#ifndef DEBUG_GLL								// デバッグ表示開始

			printf("\n[gll      ]\n");							// label
			printf("[gll_sec  ] %ld\n", gll_sec);						// gll_sec
			printf("[gll_nsec ] %ld\n", gll_nsec);						// gll_nsec
			printf("[latitude ] %lf\n", latitude);						// latitude
			printf("[longitude] %lf\n\n", longitude);					// longitude
			fflush(stdout);									// バッファフラッシュ [printf表示用]

			#endif										// デバッグ表示終了

			//-----------------------------------------------------------------------//


		}

		//-------------------------------------------------------------------------------//


		//-- [GNS メッセージ取得] --------------------------------------------------------//

		if((mode & 0x0004) == 0x0004){

			for(i = 0; i < DATASIZE; i++){

				gns[0][i] = m_LegacyData.gns.field00[i];				// データ格納 [GNS]
				if(gns[0][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gns[1][i] = m_LegacyData.gns.field01[i];				// データ格納 [GNS]
				if(gns[1][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gns[2][i] = m_LegacyData.gns.field02[i];				// データ格納 [GNS]
				if(gns[2][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gns[3][i] = m_LegacyData.gns.field03[i];				// データ格納 [GNS]
				if(gns[3][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gns[4][i] = m_LegacyData.gns.field04[i];				// データ格納 [GNS]
				if(gns[4][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gns[5][i] = m_LegacyData.gns.field05[i];				// データ格納 [GNS]
				if(gns[5][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gns[6][i] = m_LegacyData.gns.field06[i];				// データ格納 [GNS]
				if(gns[6][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gns[7][i] = m_LegacyData.gns.field07[i];				// データ格納 [GNS]
				if(gns[7][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gns[8][i] = m_LegacyData.gns.field08[i];				// データ格納 [GNS]
				if(gns[8][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gns[9][i] = m_LegacyData.gns.field09[i];				// データ格納 [GNS]
				if(gns[9][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gns[10][i] = m_LegacyData.gns.field10[i];				// データ格納 [GNS]
				if(gns[10][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gns[11][i] = m_LegacyData.gns.field11[i];				// データ格納 [GNS]
				if(gns[11][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gns[12][i] = m_LegacyData.gns.field12[i];				// データ格納 [GNS]
				if(gns[12][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gns[0][i] = m_LegacyData.gns.gp_field00[i];				// データ格納 [GPGNS]
				if(gp_gns[0][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gns[1][i] = m_LegacyData.gns.gp_field01[i];				// データ格納 [GPGNS]
				if(gp_gns[1][i] == 0x00) break;						// 終端文字チェック

			}

			strcpy(gp_gns[2], "");								// データ格納 [GPGNS]
			strcpy(gp_gns[3], "");								// データ格納 [GPGNS]
			strcpy(gp_gns[4], "");								// データ格納 [GPGNS]
			strcpy(gp_gns[5], "");								// データ格納 [GPGNS]
			strcpy(gp_gns[6], "");								// データ格納 [GPGNS]

			for(i = 0; i < DATASIZE; i++){

				gp_gns[7][i] = m_LegacyData.gns.gp_field07[i];				// データ格納 [GPGNS]
				if(gp_gns[7][i] == 0x00) break;						// 終端文字チェック

			}

			strcpy(gp_gns[8], "");								// データ格納 [GPGNS]
			strcpy(gp_gns[9], "");								// データ格納 [GPGNS]
			strcpy(gp_gns[10], "");								// データ格納 [GPGNS]

			for(i = 0; i < DATASIZE; i++){

				gp_gns[11][i] = m_LegacyData.gns.gp_field11[i];				// データ格納 [GPGNS]
				if(gp_gns[11][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gns[12][i] = m_LegacyData.gns.gp_field12[i];				// データ格納 [GPGNS]
				if(gp_gns[12][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gns[0][i] = m_LegacyData.gns.gl_field00[i];				// データ格納 [GLGNS]
				if(gl_gns[0][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gns[1][i] = m_LegacyData.gns.gl_field01[i];				// データ格納 [GLGNS]
				if(gl_gns[1][i] == 0x00) break;						// 終端文字チェック

			}

			strcpy(gl_gns[2], "");								// データ格納 [GLGNS]
			strcpy(gl_gns[3], "");								// データ格納 [GLGNS]
			strcpy(gl_gns[4], "");								// データ格納 [GLGNS]
			strcpy(gl_gns[5], "");								// データ格納 [GLGNS]
			strcpy(gl_gns[6], "");								// データ格納 [GLGNS]

			for(i = 0; i < DATASIZE; i++){

				gl_gns[7][i] = m_LegacyData.gns.gl_field07[i];				// データ格納 [GLGNS]
				if(gl_gns[7][i] == 0x00) break;						// 終端文字チェック

			}

			strcpy(gl_gns[8], "");								// データ格納 [GLGNS]
			strcpy(gl_gns[9], "");								// データ格納 [GLGNS]
			strcpy(gl_gns[10], "");								// データ格納 [GLGNS]

			for(i = 0; i < DATASIZE; i++){

				gl_gns[11][i] = m_LegacyData.gns.gl_field11[i];				// データ格納 [GLGNS]
				if(gl_gns[11][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gns[12][i] = m_LegacyData.gns.gl_field12[i];				// データ格納 [GLGNS]
				if(gl_gns[12][i] == 0x00) break;					// 終端文字チェック

			}


			//-- [タイムスタンプ処理] -----------------------------------------------//

			gns_sec = (unsigned long)(atof(gns[1]));					// UTC一時格納 [sec]
			gns_sec = (gns_sec / 10000) * 3600 + ((gns_sec % 10000) / 100) * 60
				+ (gns_sec % 100);							// タイムスタンプ格納 [sec]
			gns_nsec = (unsigned long)(fmod(atof(gns[1]), 1) * 1000000000);			// UTC一時格納 [nsec]
			if((gns_nsec % 10) != 0) gns_nsec++;						// 四捨五入処理

			gp_gns_sec = (unsigned long)(atof(gp_gns[1]));					// UTC一時格納 [sec]
			gp_gns_sec = (gp_gns_sec / 10000) * 3600 + ((gp_gns_sec % 10000) / 100) * 60
				+ (gp_gns_sec % 100);							// タイムスタンプ格納 [sec]
			gp_gns_nsec = (unsigned long)(fmod(atof(gp_gns[1]), 1) * 1000000000);		// UTC一時格納 [nsec]
			if((gp_gns_nsec % 10) != 0) gp_gns_nsec++;					// 四捨五入処理

			gl_gns_sec = (unsigned long)(atof(gl_gns[1]));					// UTC一時格納 [sec]
			gl_gns_sec = (gl_gns_sec / 10000) * 3600 + ((gl_gns_sec % 10000) / 100) * 60
				+ (gl_gns_sec % 100);							// タイムスタンプ格納 [sec]
			gl_gns_nsec = (unsigned long)(fmod(atof(gl_gns[1]), 1) * 1000000000);		// UTC一時格納 [nsec]
			if((gl_gns_nsec % 10) != 0) gl_gns_nsec++;					// 四捨五入処理

			if((gns_sec != 0) || (gns_nsec != 0)){						// 受信チェック

				m_Jgd2000Position.tm.sec = gns_sec;					// タイムスタンプ格納 [sec]
				m_Jgd2000Position.tm.nsec = gns_nsec;					// タイムスタンプ格納 [nsec]
				m_GpsData.tm.sec = gns_sec;						// タイムスタンプ格納 [sec]
				m_GpsData.tm.nsec = gns_nsec;						// タイムスタンプ格納 [nsec]
				m_GpsData.Jgd2000Position.tm.sec = gns_sec;				// タイムスタンプ格納 [sec]
				m_GpsData.Jgd2000Position.tm.nsec = gns_nsec;				// タイムスタンプ格納 [nsec]
				send_value[0] = (double)gns_sec + (double)gns_nsec / 1000000000.0;	// タイムスタンプ格納 [sec]

			}

			if((gp_gns_sec != 0) || (gp_gns_nsec != 0)){					// 受信チェック

				m_Jgd2000Position.tm.sec = gp_gns_sec;					// タイムスタンプ格納 [sec]
				m_Jgd2000Position.tm.nsec = gp_gns_nsec;				// タイムスタンプ格納 [nsec]
				m_GpsData.tm.sec = gp_gns_sec;						// タイムスタンプ格納 [sec]
				m_GpsData.tm.nsec = gp_gns_nsec;					// タイムスタンプ格納 [nsec]
				m_GpsData.Jgd2000Position.tm.sec = gp_gns_sec;				// タイムスタンプ格納 [sec]
				m_GpsData.Jgd2000Position.tm.nsec = gp_gns_nsec;			// タイムスタンプ格納 [nsec]
				send_value[0] = (double)gp_gns_sec
					+ (double)gp_gns_nsec / 1000000000.0;				// タイムスタンプ格納 [sec]

			}

			if((gl_gns_sec != 0) || (gl_gns_nsec != 0)){					// 受信チェック

				m_Jgd2000Position.tm.sec = gl_gns_sec;					// タイムスタンプ格納 [sec]
				m_Jgd2000Position.tm.nsec = gl_gns_nsec;				// タイムスタンプ格納 [nsec]
				m_GpsData.tm.sec = gl_gns_sec;						// タイムスタンプ格納 [sec]
				m_GpsData.tm.nsec = gl_gns_nsec;					// タイムスタンプ格納 [nsec]
				m_GpsData.Jgd2000Position.tm.sec = gl_gns_sec;				// タイムスタンプ格納 [sec]
				m_GpsData.Jgd2000Position.tm.nsec = gl_gns_nsec;			// タイムスタンプ格納 [nsec]
				send_value[0] = (double)gl_gns_sec
					+ (double)gl_gns_nsec / 1000000000.0;				// タイムスタンプ格納 [sec]

			}

			//-----------------------------------------------------------------------//


			//-- [緯度・経度処理] ---------------------------------------------------//

			latitude  = 0.0;								// 初期化 [latitude]
			longitude = 0.0;								// 初期化 [longitude]
			m_Jgd2000Position.latitude = latitude;						// 初期化 [latitude]
			m_GpsData.Jgd2000Position.latitude = latitude;					// 初期化 [latitude]
			m_Jgd2000Position.longitude = longitude;					// 初期化 [longitude]
			m_GpsData.Jgd2000Position.longitude = longitude;				// 初期化 [longitude]

			if((gns[3][0] == 'N') || (gns[3][0] == 'S')){					// データチェック

				if(gns[3][0] == 'N') latitude = atof(gns[2]);				// 緯度格納 [latitude]
				else if(gns[3][0] == 'S') latitude = - atof(gns[2]);			// 緯度格納 [latitude]

				latitude = (double)(((long int)latitude) * 100)
					+ fmod(latitude, 1) * 60.0;					// 緯度変換 [DMS]

				m_Jgd2000Position.latitude = latitude;					// 緯度格納 [latitude]
				m_GpsData.Jgd2000Position.latitude = latitude;				// 緯度格納 [latitude]
				send_value[1] = latitude;						// 緯度格納 [latitude]

			}

			if((gns[5][0] == 'E') || (gns[5][0] == 'W')){					// データチェック

				if(gns[5][0] == 'E') longitude = atof(gns[4]);				// 経度格納 [longitude]
				else if(gns[5][0] == 'W') longitude = - atof(gns[4]);			// 経度格納 [longitude]

				longitude = (double)(((long int)longitude) * 100)
					+ fmod(longitude, 1) * 60.0;					// 経度変換 [DMS]

				m_Jgd2000Position.longitude = longitude;				// 経度格納 [longitude]
				m_GpsData.Jgd2000Position.longitude = longitude;			// 経度格納 [longitude]
				send_value[2] = longitude;						// 経度格納 [longitude]

			}

			//-----------------------------------------------------------------------//


			//-- [デバッグgns] ------------------------------------------------------//

			#ifndef DEBUG_GNS								// デバッグ表示開始

			printf("\n[gns        ]\n");							// label
			printf("[gns_sec    ] %ld\n", gns_sec);						// gns_sec
			printf("[gns_nsec   ] %ld\n", gns_nsec);					// gns_nsec
			printf("[gp_gns_sec ] %ld\n", gp_gns_sec);					// gp_gns_sec
			printf("[gp_gns_nsec] %ld\n", gp_gns_nsec);					// gp_gns_nsec
			printf("[gl_gns_sec ] %ld\n", gl_gns_sec);					// gl_gns_sec
			printf("[gl_gns_nsec] %ld\n", gl_gns_nsec);					// gl_gns_nsec
			printf("[latitude   ] %lf\n", latitude);					// latitude
			printf("[longitude  ] %lf\n\n", longitude);					// longitude
			fflush(stdout);									// バッファフラッシュ [printf表示用]

			#endif										// デバッグ表示終了

			//-----------------------------------------------------------------------//


		}

		//-------------------------------------------------------------------------------//


		//-- [GRSメッセージ取得] --------------------------------------------------------//

		if((mode & 0x0008) == 0x0008){

			for(i = 0; i < DATASIZE; i++){

				gp_grs[0][i] = m_LegacyData.grs.gp_field00[i];				// データ格納 [GPGRS]
				if(gp_grs[0][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_grs[1][i] = m_LegacyData.grs.gp_field01[i];				// データ格納 [GPGRS]
				if(gp_grs[1][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_grs[2][i] = m_LegacyData.grs.gp_field02[i];				// データ格納 [GPGRS]
				if(gp_grs[2][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_grs[3][i] = m_LegacyData.grs.gp_field03_01[i];			// データ格納 [GPGRS]
				if(gp_grs[3][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_grs[4][i] = m_LegacyData.grs.gp_field03_02[i];			// データ格納 [GPGRS]
				if(gp_grs[4][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_grs[5][i] = m_LegacyData.grs.gp_field03_03[i];			// データ格納 [GPGRS]
				if(gp_grs[5][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_grs[6][i] = m_LegacyData.grs.gp_field03_04[i];			// データ格納 [GPGRS]
				if(gp_grs[6][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_grs[7][i] = m_LegacyData.grs.gp_field03_05[i];			// データ格納 [GPGRS]
				if(gp_grs[7][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_grs[8][i] = m_LegacyData.grs.gp_field03_06[i];			// データ格納 [GPGRS]
				if(gp_grs[8][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_grs[9][i] = m_LegacyData.grs.gp_field03_07[i];			// データ格納 [GPGRS]
				if(gp_grs[9][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_grs[10][i] = m_LegacyData.grs.gp_field03_08[i];			// データ格納 [GPGRS]
				if(gp_grs[10][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_grs[11][i] = m_LegacyData.grs.gp_field03_09[i];			// データ格納 [GPGRS]
				if(gp_grs[11][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_grs[12][i] = m_LegacyData.grs.gp_field03_10[i];			// データ格納 [GPGRS]
				if(gp_grs[12][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_grs[13][i] = m_LegacyData.grs.gp_field03_11[i];			// データ格納 [GPGRS]
				if(gp_grs[13][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_grs[14][i] = m_LegacyData.grs.gp_field03_12[i];			// データ格納 [GPGRS]
				if(gp_grs[14][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_grs[15][i] = m_LegacyData.grs.gp_field04[i];				// データ格納 [GPGRS]
				if(gp_grs[15][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_grs[0][i] = m_LegacyData.grs.gl_field00[i];				// データ格納 [GLGRS]
				if(gl_grs[0][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_grs[1][i] = m_LegacyData.grs.gl_field01[i];				// データ格納 [GLGRS]
				if(gl_grs[1][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_grs[2][i] = m_LegacyData.grs.gl_field02[i];				// データ格納 [GLGRS]
				if(gl_grs[2][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_grs[3][i] = m_LegacyData.grs.gl_field03_01[i];			// データ格納 [GLGRS]
				if(gl_grs[3][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_grs[4][i] = m_LegacyData.grs.gl_field03_02[i];			// データ格納 [GLGRS]
				if(gl_grs[4][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_grs[5][i] = m_LegacyData.grs.gl_field03_03[i];			// データ格納 [GLGRS]
				if(gl_grs[5][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_grs[6][i] = m_LegacyData.grs.gl_field03_04[i];			// データ格納 [GLGRS]
				if(gl_grs[6][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_grs[7][i] = m_LegacyData.grs.gl_field03_05[i];			// データ格納 [GLGRS]
				if(gl_grs[7][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_grs[8][i] = m_LegacyData.grs.gl_field03_06[i];			// データ格納 [GLGRS]
				if(gl_grs[8][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_grs[9][i] = m_LegacyData.grs.gl_field03_07[i];			// データ格納 [GLGRS]
				if(gl_grs[9][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_grs[10][i] = m_LegacyData.grs.gl_field03_08[i];			// データ格納 [GLGRS]
				if(gl_grs[10][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_grs[11][i] = m_LegacyData.grs.gl_field03_09[i];			// データ格納 [GLGRS]
				if(gl_grs[11][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_grs[12][i] = m_LegacyData.grs.gl_field03_10[i];			// データ格納 [GLGRS]
				if(gl_grs[12][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_grs[13][i] = m_LegacyData.grs.gl_field03_11[i];			// データ格納 [GLGRS]
				if(gl_grs[13][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_grs[14][i] = m_LegacyData.grs.gl_field03_12[i];			// データ格納 [GLGRS]
				if(gl_grs[14][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_grs[15][i] = m_LegacyData.grs.gl_field04[i];				// データ格納 [GLGRS]
				if(gl_grs[15][i] == 0x00) break;					// 終端文字チェック

			}


			//-- [タイムスタンプ処理] -----------------------------------------------//

			gp_grs_sec = (unsigned long)(atof(gp_grs[1]));					// UTC一時格納 [sec]
			gp_grs_sec = (gp_grs_sec / 10000) * 3600 + ((gp_grs_sec % 10000) / 100) * 60
				+ (gp_grs_sec % 100);							// タイムスタンプ格納 [sec]
			gp_grs_nsec = (unsigned long)(fmod(atof(gp_grs[1]), 1) * 1000000000);		// UTC一時格納 [nsec]
			if((gp_grs_nsec % 10) != 0) gp_grs_nsec++;					// 四捨五入処理

			gl_grs_sec = (unsigned long)(atof(gl_grs[1]));					// UTC一時格納 [sec]
			gl_grs_sec = (gl_grs_sec / 10000) * 3600 + ((gl_grs_sec % 10000) / 100) * 60
				+ (gl_grs_sec % 100);							// タイムスタンプ格納 [sec]
			gl_grs_nsec = (unsigned long)(fmod(atof(gl_grs[1]), 1) * 1000000000);		// UTC一時格納 [nsec]
			if((gl_grs_nsec % 10) != 0) gl_grs_nsec++;					// 四捨五入処理

			if((gp_grs_sec != 0) || (gp_grs_nsec != 0)){					// 受信チェック

				m_GpsData.tm.sec = gp_grs_sec;						// タイムスタンプ格納 [sec]
				m_GpsData.tm.nsec = gp_grs_nsec;					// タイムスタンプ格納 [nsec]

			}

			if((gl_grs_sec != 0) || (gl_grs_nsec != 0)){					// 受信チェック

				m_GpsData.tm.sec = gl_grs_sec;						// タイムスタンプ格納 [sec]
				m_GpsData.tm.nsec = gl_grs_nsec;					// タイムスタンプ格納 [nsec]

			}

			//-----------------------------------------------------------------------//


			//-- [デバッグgrs] ------------------------------------------------------//

			#ifndef DEBUG_GRS								// デバッグ表示開始

			printf("\n[grs        ]\n");							// label
			printf("[gp_grs_sec ] %ld\n", gp_grs_sec);					// gp_grs_sec
			printf("[gp_grs_nsec] %ld\n", gp_grs_nsec);					// gp_grs_nsec
			printf("[gl_grs_sec ] %ld\n", gl_grs_sec);					// gl_grs_sec
			printf("[gl_grs_nsec] %ld\n\n", gl_grs_nsec);					// gl_grs_nsec
			fflush(stdout);									// バッファフラッシュ [printf表示用]

			#endif										// デバッグ表示終了

			//-----------------------------------------------------------------------//


		}

		//-------------------------------------------------------------------------------//



		//-- [GSAメッセージ取得] --------------------------------------------------------//

		if((mode & 0x0010) == 0x0010){

			for(i = 0; i < DATASIZE; i++){

				gp_gsa[0][i] = m_LegacyData.gsa.gp_field00[i];				// データ格納 [GPGSA]
				if(gp_gsa[0][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsa[1][i] = m_LegacyData.gsa.gp_field01[i];				// データ格納 [GPGSA]
				if(gp_gsa[1][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsa[2][i] = m_LegacyData.gsa.gp_field02[i];				// データ格納 [GPGSA]
				if(gp_gsa[2][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsa[3][i] = m_LegacyData.gsa.gp_field03_01[i];			// データ格納 [GPGSA]
				if(gp_gsa[3][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsa[4][i] = m_LegacyData.gsa.gp_field03_02[i];			// データ格納 [GPGSA]
				if(gp_gsa[4][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsa[5][i] = m_LegacyData.gsa.gp_field03_03[i];			// データ格納 [GPGSA]
				if(gp_gsa[5][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsa[6][i] = m_LegacyData.gsa.gp_field03_04[i];			// データ格納 [GPGSA]
				if(gp_gsa[6][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsa[7][i] = m_LegacyData.gsa.gp_field03_05[i];			// データ格納 [GPGSA]
				if(gp_gsa[7][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsa[8][i] = m_LegacyData.gsa.gp_field03_06[i];			// データ格納 [GPGSA]
				if(gp_gsa[8][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsa[9][i] = m_LegacyData.gsa.gp_field03_07[i];			// データ格納 [GPGSA]
				if(gp_gsa[9][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsa[10][i] = m_LegacyData.gsa.gp_field03_08[i];			// データ格納 [GPGSA]
				if(gp_gsa[10][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsa[11][i] = m_LegacyData.gsa.gp_field03_09[i];			// データ格納 [GPGSA]
				if(gp_gsa[11][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsa[12][i] = m_LegacyData.gsa.gp_field03_10[i];			// データ格納 [GPGSA]
				if(gp_gsa[12][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsa[13][i] = m_LegacyData.gsa.gp_field03_11[i];			// データ格納 [GPGSA]
				if(gp_gsa[13][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsa[14][i] = m_LegacyData.gsa.gp_field03_12[i];			// データ格納 [GPGSA]
				if(gp_gsa[14][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsa[15][i] = m_LegacyData.gsa.gp_field04[i];				// データ格納 [GPGSA]
				if(gp_gsa[15][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsa[16][i] = m_LegacyData.gsa.gp_field05[i];				// データ格納 [GPGSA]
				if(gp_gsa[16][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsa[17][i] = m_LegacyData.gsa.gp_field06[i];				// データ格納 [GPGSA]
				if(gp_gsa[17][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsa[18][i] = m_LegacyData.gsa.gp_field07[i];				// データ格納 [GPGSA]
				if(gp_gsa[18][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsa[0][i] = m_LegacyData.gsa.gl_field00[i];				// データ格納 [GLGSA]
				if(gl_gsa[0][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsa[1][i] = m_LegacyData.gsa.gl_field01[i];				// データ格納 [GLGSA]
				if(gl_gsa[1][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsa[2][i] = m_LegacyData.gsa.gl_field02[i];				// データ格納 [GLGSA]
				if(gl_gsa[2][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsa[3][i] = m_LegacyData.gsa.gl_field03_01[i];			// データ格納 [GLGSA]
				if(gl_gsa[3][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsa[4][i] = m_LegacyData.gsa.gl_field03_02[i];			// データ格納 [GLGSA]
				if(gl_gsa[4][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsa[5][i] = m_LegacyData.gsa.gl_field03_03[i];			// データ格納 [GLGSA]
				if(gl_gsa[5][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsa[6][i] = m_LegacyData.gsa.gl_field03_04[i];			// データ格納 [GLGSA]
				if(gl_gsa[6][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsa[7][i] = m_LegacyData.gsa.gl_field03_05[i];			// データ格納 [GLGSA]
				if(gl_gsa[7][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsa[8][i] = m_LegacyData.gsa.gl_field03_06[i];			// データ格納 [GLGSA]
				if(gl_gsa[8][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsa[9][i] = m_LegacyData.gsa.gl_field03_07[i];			// データ格納 [GLGSA]
				if(gl_gsa[9][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsa[10][i] = m_LegacyData.gsa.gl_field03_08[i];			// データ格納 [GLGSA]
				if(gl_gsa[10][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsa[11][i] = m_LegacyData.gsa.gl_field03_09[i];			// データ格納 [GLGSA]
				if(gl_gsa[11][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsa[12][i] = m_LegacyData.gsa.gl_field03_10[i];			// データ格納 [GLGSA]
				if(gl_gsa[12][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsa[13][i] = m_LegacyData.gsa.gl_field03_11[i];			// データ格納 [GLGSA]
				if(gl_gsa[13][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsa[14][i] = m_LegacyData.gsa.gl_field03_12[i];			// データ格納 [GLGSA]
				if(gl_gsa[14][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsa[15][i] = m_LegacyData.gsa.gl_field04[i];				// データ格納 [GLGSA]
				if(gl_gsa[15][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsa[16][i] = m_LegacyData.gsa.gl_field05[i];				// データ格納 [GLGSA]
				if(gl_gsa[16][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsa[17][i] = m_LegacyData.gsa.gl_field06[i];				// データ格納 [GLGSA]
				if(gl_gsa[17][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsa[18][i] = m_LegacyData.gsa.gl_field07[i];				// データ格納 [GLGSA]
				if(gl_gsa[18][i] == 0x00) break;					// 終端文字チェック

			}

		}

		//-------------------------------------------------------------------------------//


		//-- [GSTメッセージ取得] --------------------------------------------------------//

		if((mode & 0x0020) == 0x0020){

			for(i = 0; i < DATASIZE; i++){

				gst[0][i] = m_LegacyData.gst.field00[i];				// データ格納 [GST]
				if(gst[0][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gst[1][i] = m_LegacyData.gst.field01[i];				// データ格納 [GST]
				if(gst[1][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gst[2][i] = m_LegacyData.gst.field02[i];				// データ格納 [GST]
				if(gst[2][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gst[3][i] = m_LegacyData.gst.field03[i];				// データ格納 [GST]
				if(gst[3][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gst[4][i] = m_LegacyData.gst.field04[i];				// データ格納 [GST]
				if(gst[4][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gst[5][i] = m_LegacyData.gst.field05[i];				// データ格納 [GST]
				if(gst[5][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gst[6][i] = m_LegacyData.gst.field06[i];				// データ格納 [GST]
				if(gst[6][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gst[7][i] = m_LegacyData.gst.field07[i];				// データ格納 [GST]
				if(gst[7][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gst[8][i] = m_LegacyData.gst.field08[i];				// データ格納 [GST]
				if(gst[8][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gst[9][i] = m_LegacyData.gst.field09[i];				// データ格納 [GST]
				if(gst[9][i] == 0x00) break;						// 終端文字チェック

			}


			//-- [タイムスタンプ処理] -----------------------------------------------//

			gst_sec = (unsigned long)(atof(gst[1]));					// UTC一時格納 [sec]
			gst_sec = (gst_sec / 10000) * 3600 + ((gst_sec % 10000) / 100) * 60
				+ (gst_sec % 100);							// タイムスタンプ格納 [sec]
			gst_nsec = (unsigned long)(fmod(atof(gst[1]), 1) * 1000000000);			// UTC一時格納 [nsec]
			if((gst_nsec % 10) != 0) gst_nsec++;						// 四捨五入処理

			if((gst_sec != 0) || (gst_nsec != 0)){						// 受信チェック

				m_GpsData.tm.sec = gst_sec;						// タイムスタンプ格納 [sec]
				m_GpsData.tm.nsec = gst_nsec;						// タイムスタンプ格納 [nsec]

			}

			//-----------------------------------------------------------------------//


			//-- [デバッグgst] ------------------------------------------------------//

			#ifndef DEBUG_GST								// デバッグ表示開始

			printf("\n[gst     ]\n");							// label
			printf("[gst_sec ] %ld\n", gst_sec);						// gst_sec
			printf("[gst_nsec] %ld\n\n", gst_nsec);						// gst_nsec
			fflush(stdout);									// バッファフラッシュ [printf表示用]

			#endif										// デバッグ表示終了

			//-----------------------------------------------------------------------//


		}

		//-------------------------------------------------------------------------------//


		//-- [GSVメッセージ取得] --------------------------------------------------------//

		if((mode & 0x0040) == 0x0040){

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[0][0][i] = m_LegacyData.gsv.gp1_field00[i];			// データ格納 [GPGSV]
				if(gp_gsv[0][0][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[0][1][i] = m_LegacyData.gsv.gp1_field01[i];			// データ格納 [GPGSV]
				if(gp_gsv[0][1][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[0][2][i] = m_LegacyData.gsv.gp1_field02[i];			// データ格納 [GPGSV]
				if(gp_gsv[0][2][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[0][3][i] = m_LegacyData.gsv.gp1_field03[i];			// データ格納 [GPGSV]
				if(gp_gsv[0][3][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[0][4][i] = m_LegacyData.gsv.gp1_field04_1_1[i];			// データ格納 [GPGSV]
				if(gp_gsv[0][4][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[0][5][i] = m_LegacyData.gsv.gp1_field04_1_2[i];			// データ格納 [GPGSV]
				if(gp_gsv[0][5][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[0][6][i] = m_LegacyData.gsv.gp1_field04_1_3[i];			// データ格納 [GPGSV]
				if(gp_gsv[0][6][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[0][7][i] = m_LegacyData.gsv.gp1_field04_1_4[i];			// データ格納 [GPGSV]
				if(gp_gsv[0][7][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[0][8][i] = m_LegacyData.gsv.gp1_field04_2_1[i];			// データ格納 [GPGSV]
				if(gp_gsv[0][8][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[0][9][i] = m_LegacyData.gsv.gp1_field04_2_2[i];			// データ格納 [GPGSV]
				if(gp_gsv[0][9][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[0][10][i] = m_LegacyData.gsv.gp1_field04_2_3[i];			// データ格納 [GPGSV]
				if(gp_gsv[0][10][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[0][11][i] = m_LegacyData.gsv.gp1_field04_2_4[i];			// データ格納 [GPGSV]
				if(gp_gsv[0][11][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[0][12][i] = m_LegacyData.gsv.gp1_field04_3_1[i];			// データ格納 [GPGSV]
				if(gp_gsv[0][12][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[0][13][i] = m_LegacyData.gsv.gp1_field04_3_2[i];			// データ格納 [GPGSV]
				if(gp_gsv[0][13][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[0][14][i] = m_LegacyData.gsv.gp1_field04_3_3[i];			// データ格納 [GPGSV]
				if(gp_gsv[0][14][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[0][15][i] = m_LegacyData.gsv.gp1_field04_3_4[i];			// データ格納 [GPGSV]
				if(gp_gsv[0][15][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[0][16][i] = m_LegacyData.gsv.gp1_field04_4_1[i];			// データ格納 [GPGSV]
				if(gp_gsv[0][16][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[0][17][i] = m_LegacyData.gsv.gp1_field04_4_2[i];			// データ格納 [GPGSV]
				if(gp_gsv[0][17][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[0][18][i] = m_LegacyData.gsv.gp1_field04_4_3[i];			// データ格納 [GPGSV]
				if(gp_gsv[0][18][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[0][19][i] = m_LegacyData.gsv.gp1_field04_4_4[i];			// データ格納 [GPGSV]
				if(gp_gsv[0][19][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[0][20][i] = m_LegacyData.gsv.gp1_field05[i];			// データ格納 [GPGSV]
				if(gp_gsv[0][20][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[1][0][i] = m_LegacyData.gsv.gp2_field00[i];			// データ格納 [GPGSV]
				if(gp_gsv[1][0][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[1][1][i] = m_LegacyData.gsv.gp2_field01[i];			// データ格納 [GPGSV]
				if(gp_gsv[1][1][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[1][2][i] = m_LegacyData.gsv.gp2_field02[i];			// データ格納 [GPGSV]
				if(gp_gsv[1][2][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[1][3][i] = m_LegacyData.gsv.gp2_field03[i];			// データ格納 [GPGSV]
				if(gp_gsv[1][3][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[1][4][i] = m_LegacyData.gsv.gp2_field04_1_1[i];			// データ格納 [GPGSV]
				if(gp_gsv[1][4][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[1][5][i] = m_LegacyData.gsv.gp2_field04_1_2[i];			// データ格納 [GPGSV]
				if(gp_gsv[1][5][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[1][6][i] = m_LegacyData.gsv.gp2_field04_1_3[i];			// データ格納 [GPGSV]
				if(gp_gsv[1][6][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[1][7][i] = m_LegacyData.gsv.gp2_field04_1_4[i];			// データ格納 [GPGSV]
				if(gp_gsv[1][7][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[1][8][i] = m_LegacyData.gsv.gp2_field04_2_1[i];			// データ格納 [GPGSV]
				if(gp_gsv[1][8][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[1][9][i] = m_LegacyData.gsv.gp2_field04_2_2[i];			// データ格納 [GPGSV]
				if(gp_gsv[1][9][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[1][10][i] = m_LegacyData.gsv.gp2_field04_2_3[i];			// データ格納 [GPGSV]
				if(gp_gsv[1][10][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[1][11][i] = m_LegacyData.gsv.gp2_field04_2_4[i];			// データ格納 [GPGSV]
				if(gp_gsv[1][11][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[1][12][i] = m_LegacyData.gsv.gp2_field04_3_1[i];			// データ格納 [GPGSV]
				if(gp_gsv[1][12][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[1][13][i] = m_LegacyData.gsv.gp2_field04_3_2[i];			// データ格納 [GPGSV]
				if(gp_gsv[1][13][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[1][14][i] = m_LegacyData.gsv.gp2_field04_3_3[i];			// データ格納 [GPGSV]
				if(gp_gsv[1][14][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[1][15][i] = m_LegacyData.gsv.gp2_field04_3_4[i];			// データ格納 [GPGSV]
				if(gp_gsv[1][15][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[1][16][i] = m_LegacyData.gsv.gp2_field04_4_1[i];			// データ格納 [GPGSV]
				if(gp_gsv[1][16][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[1][17][i] = m_LegacyData.gsv.gp2_field04_4_2[i];			// データ格納 [GPGSV]
				if(gp_gsv[1][17][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[1][18][i] = m_LegacyData.gsv.gp2_field04_4_3[i];			// データ格納 [GPGSV]
				if(gp_gsv[1][18][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[1][19][i] = m_LegacyData.gsv.gp2_field04_4_4[i];			// データ格納 [GPGSV]
				if(gp_gsv[1][19][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[1][20][i] = m_LegacyData.gsv.gp2_field05[i];			// データ格納 [GPGSV]
				if(gp_gsv[1][20][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[2][0][i] = m_LegacyData.gsv.gp3_field00[i];			// データ格納 [GPGSV]
				if(gp_gsv[2][0][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[2][1][i] = m_LegacyData.gsv.gp3_field01[i];			// データ格納 [GPGSV]
				if(gp_gsv[2][1][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[2][2][i] = m_LegacyData.gsv.gp3_field02[i];			// データ格納 [GPGSV]
				if(gp_gsv[2][2][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[2][3][i] = m_LegacyData.gsv.gp3_field03[i];			// データ格納 [GPGSV]
				if(gp_gsv[2][3][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[2][4][i] = m_LegacyData.gsv.gp3_field04_1_1[i];			// データ格納 [GPGSV]
				if(gp_gsv[2][4][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[2][5][i] = m_LegacyData.gsv.gp3_field04_1_2[i];			// データ格納 [GPGSV]
				if(gp_gsv[2][5][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[2][6][i] = m_LegacyData.gsv.gp3_field04_1_3[i];			// データ格納 [GPGSV]
				if(gp_gsv[2][6][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[2][7][i] = m_LegacyData.gsv.gp3_field04_1_4[i];			// データ格納 [GPGSV]
				if(gp_gsv[2][7][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[2][8][i] = m_LegacyData.gsv.gp3_field04_2_1[i];			// データ格納 [GPGSV]
				if(gp_gsv[2][8][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[2][9][i] = m_LegacyData.gsv.gp3_field04_2_2[i];			// データ格納 [GPGSV]
				if(gp_gsv[2][9][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[2][10][i] = m_LegacyData.gsv.gp3_field04_2_3[i];			// データ格納 [GPGSV]
				if(gp_gsv[2][10][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[2][11][i] = m_LegacyData.gsv.gp3_field04_2_4[i];			// データ格納 [GPGSV]
				if(gp_gsv[2][11][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[2][12][i] = m_LegacyData.gsv.gp3_field04_3_1[i];			// データ格納 [GPGSV]
				if(gp_gsv[2][12][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[2][13][i] = m_LegacyData.gsv.gp3_field04_3_2[i];			// データ格納 [GPGSV]
				if(gp_gsv[2][13][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[2][14][i] = m_LegacyData.gsv.gp3_field04_3_3[i];			// データ格納 [GPGSV]
				if(gp_gsv[2][14][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[2][15][i] = m_LegacyData.gsv.gp3_field04_3_4[i];			// データ格納 [GPGSV]
				if(gp_gsv[2][15][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[2][16][i] = m_LegacyData.gsv.gp3_field04_4_1[i];			// データ格納 [GPGSV]
				if(gp_gsv[2][16][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[2][17][i] = m_LegacyData.gsv.gp3_field04_4_2[i];			// データ格納 [GPGSV]
				if(gp_gsv[2][17][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[2][18][i] = m_LegacyData.gsv.gp3_field04_4_3[i];			// データ格納 [GPGSV]
				if(gp_gsv[2][18][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[2][19][i] = m_LegacyData.gsv.gp3_field04_4_4[i];			// データ格納 [GPGSV]
				if(gp_gsv[2][19][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gp_gsv[2][20][i] = m_LegacyData.gsv.gp3_field05[i];			// データ格納 [GPGSV]
				if(gp_gsv[2][20][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[0][0][i] = m_LegacyData.gsv.gl1_field00[i];			// データ格納 [GLGSV]
				if(gl_gsv[0][0][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[0][1][i] = m_LegacyData.gsv.gl1_field01[i];			// データ格納 [GLGSV]
				if(gl_gsv[0][1][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[0][2][i] = m_LegacyData.gsv.gl1_field02[i];			// データ格納 [GLGSV]
				if(gl_gsv[0][2][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[0][3][i] = m_LegacyData.gsv.gl1_field03[i];			// データ格納 [GLGSV]
				if(gl_gsv[0][3][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[0][4][i] = m_LegacyData.gsv.gl1_field04_1_1[i];			// データ格納 [GLGSV]
				if(gl_gsv[0][4][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[0][5][i] = m_LegacyData.gsv.gl1_field04_1_2[i];			// データ格納 [GLGSV]
				if(gl_gsv[0][5][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[0][6][i] = m_LegacyData.gsv.gl1_field04_1_3[i];			// データ格納 [GLGSV]
				if(gl_gsv[0][6][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[0][7][i] = m_LegacyData.gsv.gl1_field04_1_4[i];			// データ格納 [GLGSV]
				if(gl_gsv[0][7][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[0][8][i] = m_LegacyData.gsv.gl1_field04_2_1[i];			// データ格納 [GLGSV]
				if(gl_gsv[0][8][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[0][9][i] = m_LegacyData.gsv.gl1_field04_2_2[i];			// データ格納 [GLGSV]
				if(gl_gsv[0][9][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[0][10][i] = m_LegacyData.gsv.gl1_field04_2_3[i];			// データ格納 [GLGSV]
				if(gl_gsv[0][10][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[0][11][i] = m_LegacyData.gsv.gl1_field04_2_4[i];			// データ格納 [GLGSV]
				if(gl_gsv[0][11][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[0][12][i] = m_LegacyData.gsv.gl1_field04_3_1[i];			// データ格納 [GLGSV]
				if(gl_gsv[0][12][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[0][13][i] = m_LegacyData.gsv.gl1_field04_3_2[i];			// データ格納 [GLGSV]
				if(gl_gsv[0][13][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[0][14][i] = m_LegacyData.gsv.gl1_field04_3_3[i];			// データ格納 [GLGSV]
				if(gl_gsv[0][14][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[0][15][i] = m_LegacyData.gsv.gl1_field04_3_4[i];			// データ格納 [GLGSV]
				if(gl_gsv[0][15][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[0][16][i] = m_LegacyData.gsv.gl1_field04_4_1[i];			// データ格納 [GLGSV]
				if(gl_gsv[0][16][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[0][17][i] = m_LegacyData.gsv.gl1_field04_4_2[i];			// データ格納 [GLGSV]
				if(gl_gsv[0][17][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[0][18][i] = m_LegacyData.gsv.gl1_field04_4_3[i];			// データ格納 [GLGSV]
				if(gl_gsv[0][18][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[0][19][i] = m_LegacyData.gsv.gl1_field04_4_4[i];			// データ格納 [GLGSV]
				if(gl_gsv[0][19][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[0][20][i] = m_LegacyData.gsv.gl1_field05[i];			// データ格納 [GLGSV]
				if(gl_gsv[0][20][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[1][0][i] = m_LegacyData.gsv.gl2_field00[i];			// データ格納 [GLGSV]
				if(gl_gsv[1][0][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[1][1][i] = m_LegacyData.gsv.gl2_field01[i];			// データ格納 [GLGSV]
				if(gl_gsv[1][1][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[1][2][i] = m_LegacyData.gsv.gl2_field02[i];			// データ格納 [GLGSV]
				if(gl_gsv[1][2][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[1][3][i] = m_LegacyData.gsv.gl2_field03[i];			// データ格納 [GLGSV]
				if(gl_gsv[1][3][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[1][4][i] = m_LegacyData.gsv.gl2_field04_1_1[i];			// データ格納 [GLGSV]
				if(gl_gsv[1][4][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[1][5][i] = m_LegacyData.gsv.gl2_field04_1_2[i];			// データ格納 [GLGSV]
				if(gl_gsv[1][5][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[1][6][i] = m_LegacyData.gsv.gl2_field04_1_3[i];			// データ格納 [GLGSV]
				if(gl_gsv[1][6][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[1][7][i] = m_LegacyData.gsv.gl2_field04_1_4[i];			// データ格納 [GLGSV]
				if(gl_gsv[1][7][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[1][8][i] = m_LegacyData.gsv.gl2_field04_2_1[i];			// データ格納 [GLGSV]
				if(gl_gsv[1][8][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[1][9][i] = m_LegacyData.gsv.gl2_field04_2_2[i];			// データ格納 [GLGSV]
				if(gl_gsv[1][9][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[1][10][i] = m_LegacyData.gsv.gl2_field04_2_3[i];			// データ格納 [GLGSV]
				if(gl_gsv[1][10][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[1][11][i] = m_LegacyData.gsv.gl2_field04_2_4[i];			// データ格納 [GLGSV]
				if(gl_gsv[1][11][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[1][12][i] = m_LegacyData.gsv.gl2_field04_3_1[i];			// データ格納 [GLGSV]
				if(gl_gsv[1][12][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[1][13][i] = m_LegacyData.gsv.gl2_field04_3_2[i];			// データ格納 [GLGSV]
				if(gl_gsv[1][13][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[1][14][i] = m_LegacyData.gsv.gl2_field04_3_3[i];			// データ格納 [GLGSV]
				if(gl_gsv[1][14][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[1][15][i] = m_LegacyData.gsv.gl2_field04_3_4[i];			// データ格納 [GLGSV]
				if(gl_gsv[1][15][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[1][16][i] = m_LegacyData.gsv.gl2_field04_4_1[i];			// データ格納 [GLGSV]
				if(gl_gsv[1][16][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[1][17][i] = m_LegacyData.gsv.gl2_field04_4_2[i];			// データ格納 [GLGSV]
				if(gl_gsv[1][17][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[1][18][i] = m_LegacyData.gsv.gl2_field04_4_3[i];			// データ格納 [GLGSV]
				if(gl_gsv[1][18][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[1][19][i] = m_LegacyData.gsv.gl2_field04_4_4[i];			// データ格納 [GLGSV]
				if(gl_gsv[1][19][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[1][20][i] = m_LegacyData.gsv.gl2_field05[i];			// データ格納 [GLGSV]
				if(gl_gsv[1][20][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[2][0][i] = m_LegacyData.gsv.gl3_field00[i];			// データ格納 [GLGSV]
				if(gl_gsv[2][0][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[2][1][i] = m_LegacyData.gsv.gl3_field01[i];			// データ格納 [GLGSV]
				if(gl_gsv[2][1][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[2][2][i] = m_LegacyData.gsv.gl3_field02[i];			// データ格納 [GLGSV]
				if(gl_gsv[2][2][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[2][3][i] = m_LegacyData.gsv.gl3_field03[i];			// データ格納 [GLGSV]
				if(gl_gsv[2][3][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[2][4][i] = m_LegacyData.gsv.gl3_field04_1_1[i];			// データ格納 [GLGSV]
				if(gl_gsv[2][4][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[2][5][i] = m_LegacyData.gsv.gl3_field04_1_2[i];			// データ格納 [GLGSV]
				if(gl_gsv[2][5][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[2][6][i] = m_LegacyData.gsv.gl3_field04_1_3[i];			// データ格納 [GLGSV]
				if(gl_gsv[2][6][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[2][7][i] = m_LegacyData.gsv.gl3_field04_1_4[i];			// データ格納 [GLGSV]
				if(gl_gsv[2][7][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[2][8][i] = m_LegacyData.gsv.gl3_field04_2_1[i];			// データ格納 [GLGSV]
				if(gl_gsv[2][8][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[2][9][i] = m_LegacyData.gsv.gl3_field04_2_2[i];			// データ格納 [GLGSV]
				if(gl_gsv[2][9][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[2][10][i] = m_LegacyData.gsv.gl3_field04_2_3[i];			// データ格納 [GLGSV]
				if(gl_gsv[2][10][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[2][11][i] = m_LegacyData.gsv.gl3_field04_2_4[i];			// データ格納 [GLGSV]
				if(gl_gsv[2][11][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[2][12][i] = m_LegacyData.gsv.gl3_field04_3_1[i];			// データ格納 [GLGSV]
				if(gl_gsv[2][12][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[2][13][i] = m_LegacyData.gsv.gl3_field04_3_2[i];			// データ格納 [GLGSV]
				if(gl_gsv[2][13][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[2][14][i] = m_LegacyData.gsv.gl3_field04_3_3[i];			// データ格納 [GLGSV]
				if(gl_gsv[2][14][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[2][15][i] = m_LegacyData.gsv.gl3_field04_3_4[i];			// データ格納 [GLGSV]
				if(gl_gsv[2][15][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[2][16][i] = m_LegacyData.gsv.gl3_field04_4_1[i];			// データ格納 [GLGSV]
				if(gl_gsv[2][16][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[2][17][i] = m_LegacyData.gsv.gl3_field04_4_2[i];			// データ格納 [GLGSV]
				if(gl_gsv[2][17][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[2][18][i] = m_LegacyData.gsv.gl3_field04_4_3[i];			// データ格納 [GLGSV]
				if(gl_gsv[2][18][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[2][19][i] = m_LegacyData.gsv.gl3_field04_4_4[i];			// データ格納 [GLGSV]
				if(gl_gsv[2][19][i] == 0x00) break;					// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				gl_gsv[2][20][i] = m_LegacyData.gsv.gl3_field05[i];			// データ格納 [GLGSV]
				if(gl_gsv[2][20][i] == 0x00) break;					// 終端文字チェック

			}

		}

		//-------------------------------------------------------------------------------//


		//-- [HDTメッセージ取得] --------------------------------------------------------//

		if((mode & 0x0080) == 0x0080){

			for(i = 0; i < DATASIZE; i++){

				hdt[0][i] = m_LegacyData.hdt.field00[i];				// データ格納 [HDT]
				if(hdt[0][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				hdt[1][i] = m_LegacyData.hdt.field01[i];				// データ格納 [HDT]
				if(hdt[1][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				hdt[2][i] = m_LegacyData.hdt.field02[i];				// データ格納 [HDT]
				if(hdt[2][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				hdt[3][i] = m_LegacyData.hdt.field03[i];				// データ格納 [HDT]
				if(hdt[3][i] == 0x00) break;						// 終端文字チェック

			}

		}

		//-------------------------------------------------------------------------------//


		//-- [RMCメッセージ取得] --------------------------------------------------------//

		if((mode & 0x0100) == 0x0100){

			for(i = 0; i < DATASIZE; i++){

				rmc[0][i] = m_LegacyData.rmc.field00[i];				// データ格納 [RMC]
				if(rmc[0][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				rmc[1][i] = m_LegacyData.rmc.field01[i];				// データ格納 [RMC]
				if(rmc[1][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				rmc[2][i] = m_LegacyData.rmc.field02[i];				// データ格納 [RMC]
				if(rmc[2][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				rmc[3][i] = m_LegacyData.rmc.field03[i];				// データ格納 [RMC]
				if(rmc[3][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				rmc[4][i] = m_LegacyData.rmc.field04[i];				// データ格納 [RMC]
				if(rmc[4][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				rmc[5][i] = m_LegacyData.rmc.field05[i];				// データ格納 [RMC]
				if(rmc[5][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				rmc[6][i] = m_LegacyData.rmc.field06[i];				// データ格納 [RMC]
				if(rmc[6][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				rmc[7][i] = m_LegacyData.rmc.field07[i];				// データ格納 [RMC]
				if(rmc[7][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				rmc[8][i] = m_LegacyData.rmc.field08[i];				// データ格納 [RMC]
				if(rmc[8][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				rmc[9][i] = m_LegacyData.rmc.field09[i];				// データ格納 [RMC]
				if(rmc[9][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				rmc[10][i] = m_LegacyData.rmc.field10[i];				// データ格納 [RMC]
				if(rmc[10][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				rmc[11][i] = m_LegacyData.rmc.field11[i];				// データ格納 [RMC]
				if(rmc[11][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				rmc[12][i] = m_LegacyData.rmc.field12[i];				// データ格納 [RMC]
				if(rmc[12][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				rmc[13][i] = m_LegacyData.rmc.field13[i];				// データ格納 [RMC]
				if(rmc[13][i] == 0x00) break;						// 終端文字チェック

			}


			//-- [タイムスタンプ処理] -----------------------------------------------//

			rmc_sec = (unsigned long)(atof(rmc[1]));					// UTC一時格納 [sec]
			rmc_sec = (rmc_sec / 10000) * 3600 + ((rmc_sec % 10000) / 100) * 60
				+ (rmc_sec % 100);							// タイムスタンプ格納 [sec]
			rmc_nsec = (unsigned long)(fmod(atof(rmc[1]), 1) * 1000000000);			// UTC一時格納 [nsec]
			if((rmc_nsec % 10) != 0) rmc_nsec++;						// 四捨五入処理

			if((rmc_sec != 0) || (rmc_nsec != 0)){						// 受信チェック

				m_Jgd2000Position.tm.sec = rmc_sec;					// タイムスタンプ格納 [sec]
				m_Jgd2000Position.tm.nsec = rmc_nsec;					// タイムスタンプ格納 [nsec]
				m_GpsData.tm.sec = rmc_sec;						// タイムスタンプ格納 [sec]
				m_GpsData.tm.nsec = rmc_nsec;						// タイムスタンプ格納 [nsec]
				m_GpsData.Jgd2000Position.tm.sec = rmc_sec;				// タイムスタンプ格納 [sec]
				m_GpsData.Jgd2000Position.tm.nsec = rmc_nsec;				// タイムスタンプ格納 [nsec]
				send_value[0] = (double)rmc_sec + (double)rmc_nsec / 1000000000.0;	// タイムスタンプ格納 [sec]

			}

			//-----------------------------------------------------------------------//


			//-- [緯度・経度処理] ---------------------------------------------------//

			latitude  = 0.0;								// 初期化 [latitude]
			longitude = 0.0;								// 初期化 [longitude]
			m_Jgd2000Position.latitude = latitude;						// 初期化 [latitude]
			m_GpsData.Jgd2000Position.latitude = latitude;					// 初期化 [latitude]
			m_Jgd2000Position.longitude = longitude;					// 初期化 [longitude]
			m_GpsData.Jgd2000Position.longitude = longitude;				// 初期化 [longitude]

			if((rmc[4][0] == 'N') || (rmc[4][0] == 'S')){					// データチェック

				if(rmc[4][0] == 'N') latitude = atof(rmc[3]);				// 緯度格納 [latitude]
				else if(rmc[4][0] == 'S') latitude = - atof(rmc[3]);			// 緯度格納 [latitude]

				latitude = (double)(((long int)latitude) * 100)
					+ fmod(latitude, 1) * 60.0;					// 緯度変換 [DMS]

				m_Jgd2000Position.latitude = latitude;					// 緯度格納 [latitude]
				m_GpsData.Jgd2000Position.latitude = latitude;				// 緯度格納 [latitude]
				send_value[1] = latitude;						// 緯度格納 [latitude]

			}

			if((rmc[6][0] == 'E') || (rmc[6][0] == 'W')){					// データチェック

				if(rmc[6][0] == 'E') longitude = atof(rmc[5]);				// 経度格納 [longitude]
				else if(rmc[6][0] == 'W') longitude = - atof(rmc[5]);			// 経度格納 [longitude]

				longitude = (double)(((long int)longitude) * 100)
					+ fmod(longitude, 1) * 60.0;					// 経度変換 [DMS]

				m_Jgd2000Position.longitude = longitude;				// 経度格納 [longitude]
				m_GpsData.Jgd2000Position.longitude = longitude;			// 経度格納 [longitude]
				send_value[2] = longitude;						// 経度格納 [longitude]

			}

			//-----------------------------------------------------------------------//


			//-- [デバッグrmc] ------------------------------------------------------//

			#ifndef DEBUG_RMC								// デバッグ表示開始

			printf("\n[rmc      ]\n");							// label
			printf("[rmc_sec  ] %ld\n", rmc_sec);						// rmc_sec
			printf("[rmc_nsec ] %ld\n", rmc_nsec);						// rmc_nsec
			printf("[latitude ] %lf\n", latitude);						// latitude
			printf("[longitude] %lf\n\n", longitude);					// longitude
			fflush(stdout);									// バッファフラッシュ [printf表示用]

			#endif										// デバッグ表示終了

			//-----------------------------------------------------------------------//


		}

		//-------------------------------------------------------------------------------//


		//-- [VTGメッセージ取得] --------------------------------------------------------//

		if((mode & 0x0200) == 0x0200){

			for(i = 0; i < DATASIZE; i++){

				vtg[0][i] = m_LegacyData.vtg.field00[i];				// データ格納 [VTG]
				if(vtg[0][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				vtg[1][i] = m_LegacyData.vtg.field01[i];				// データ格納 [VTG]
				if(vtg[1][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				vtg[2][i] = m_LegacyData.vtg.field02[i];				// データ格納 [VTG]
				if(vtg[2][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				vtg[3][i] = m_LegacyData.vtg.field03[i];				// データ格納 [VTG]
				if(vtg[3][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				vtg[4][i] = m_LegacyData.vtg.field04[i];				// データ格納 [VTG]
				if(vtg[4][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				vtg[5][i] = m_LegacyData.vtg.field05[i];				// データ格納 [VTG]
				if(vtg[5][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				vtg[6][i] = m_LegacyData.vtg.field06[i];				// データ格納 [VTG]
				if(vtg[6][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				vtg[7][i] = m_LegacyData.vtg.field07[i];				// データ格納 [VTG]
				if(vtg[7][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				vtg[8][i] = m_LegacyData.vtg.field08[i];				// データ格納 [VTG]
				if(vtg[8][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				vtg[9][i] = m_LegacyData.vtg.field09[i];				// データ格納 [VTG]
				if(vtg[9][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				vtg[10][i] = m_LegacyData.vtg.field10[i];				// データ格納 [VTG]
				if(vtg[10][i] == 0x00) break;						// 終端文字チェック

			}

		}

		//-------------------------------------------------------------------------------//


		//-- [ZDAメッセージ取得] --------------------------------------------------------//

		if((mode & 0x0400) == 0x0400){

			for(i = 0; i < DATASIZE; i++){

				zda[0][i] = m_LegacyData.zda.field00[i];				// データ格納 [ZDA]
				if(zda[0][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				zda[1][i] = m_LegacyData.zda.field01[i];				// データ格納 [ZDA]
				if(zda[1][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				zda[2][i] = m_LegacyData.zda.field02[i];				// データ格納 [ZDA]
				if(zda[2][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				zda[3][i] = m_LegacyData.zda.field03[i];				// データ格納 [ZDA]
				if(zda[3][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				zda[4][i] = m_LegacyData.zda.field04[i];				// データ格納 [ZDA]
				if(zda[4][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				zda[5][i] = m_LegacyData.zda.field05[i];				// データ格納 [ZDA]
				if(zda[5][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				zda[6][i] = m_LegacyData.zda.field06[i];				// データ格納 [ZDA]
				if(zda[6][i] == 0x00) break;						// 終端文字チェック

			}

			for(i = 0; i < DATASIZE; i++){

				zda[7][i] = m_LegacyData.zda.field07[i];				// データ格納 [ZDA]
				if(zda[7][i] == 0x00) break;						// 終端文字チェック

			}


			//-- [タイムスタンプ処理] -----------------------------------------------//

			zda_sec = (unsigned long)(atof(zda[1]));					// UTC一時格納 [sec]
			zda_sec = (zda_sec / 10000) * 3600 + ((zda_sec % 10000) / 100) * 60
				+ (zda_sec % 100);							// タイムスタンプ格納 [sec]
			zda_nsec = (unsigned long)(fmod(atof(zda[1]), 1) * 1000000000);			// UTC一時格納 [nsec]
			if((zda_nsec % 10) != 0) zda_nsec++;						// 四捨五入処理

			if((zda_sec != 0) || (zda_nsec != 0)){						// 受信チェック

				m_GpsData.tm.sec = zda_sec;						// タイムスタンプ格納 [sec]
				m_GpsData.tm.nsec = zda_nsec;						// タイムスタンプ格納 [nsec]

			}

			//-----------------------------------------------------------------------//


			//-- [デバッグzda] ------------------------------------------------------//

			#ifndef DEBUG_ZDA								// デバッグ表示開始

			printf("\n[zda     ]\n");							// label
			printf("[zda_sec ] %ld\n", zda_sec);						// zda_sec
			printf("[zda_nsec] %ld\n\n", zda_nsec);						// zda_nsec
			fflush(stdout);									// バッファフラッシュ [printf表示用]

			#endif										// デバッグ表示終了

			//-----------------------------------------------------------------------//


		}

		//-------------------------------------------------------------------------------//


		//-------------------------------------------------------------------------------//


		//-- [デバッグinport] -----------------------------------------------------------//

		#ifndef DEBUG_INPORT									// デバッグ表示開始

		printf("\n[inport]\n");									// label
		printf("[Timestamp] %lf\n", (double)sec + (double)nsec / 1000000000.0);			// tm
		printf("[Mode     ] %4d -> %d%d%d%d%d%d%d%d%d%d%d\n", mode, (mode & 0x0400) >> 10,
			(mode & 0x0200) >> 9, (mode & 0x0100) >> 8, (mode & 0x0080) >> 7,
			(mode & 0x0040) >> 6, (mode & 0x0020) >> 5, (mode & 0x0010) >> 4,
			(mode & 0x0008) >> 3, (mode & 0x0004) >> 2, (mode & 0x0002) >> 1,
			(mode & 0x0001));								// mode
		printf("[GGA      ] ");									// gga
		for(i = 0; i < 15; i++) printf("%s,", gga[i]);						// gga
		printf("%s\n", gga[i]);									// gga
		printf("[GLL      ] ");									// gll
		for(i = 0; i < 8; i++) printf("%s,", gll[i]);						// gll
		printf("%s\n", gll[i]);									// gll
		printf("[GNS      ] ");									// gns
		for(i = 0; i < 12; i++) printf("%s,", gns[i]);						// gns
		printf("%s\n", gns[i]);									// gns
		printf("            ");									// gp_gns
		for(i = 0; i < 12; i++) printf("%s,", gp_gns[i]);					// gp_gns
		printf("%s\n", gp_gns[i]);								// gp_gns
		printf("            ");									// gl_gns
		for(i = 0; i < 12; i++) printf("%s,", gl_gns[i]);					// gl_gns
		printf("%s\n", gl_gns[i]);								// gl_gns
		printf("[GRS      ] ");									// gp_grs
		for(i = 0; i < 15; i++) printf("%s,", gp_grs[i]);					// gp_grs
		printf("%s\n", gp_grs[i]);								// gp_grs
		printf("            ");									// gl_grs
		for(i = 0; i < 15; i++) printf("%s,", gl_grs[i]);					// gl_grs
		printf("%s\n", gl_grs[i]);								// gl_grs
		printf("[GSA      ] ");									// gp_gsa
		for(i = 0; i < 18; i++) printf("%s,", gp_gsa[i]);					// gp_gsa
		printf("%s\n", gp_gsa[i]);								// gp_gsa
		printf("            ");									// gl_gsa
		for(i = 0; i < 18; i++) printf("%s,", gl_gsa[i]);					// gl_gsa
		printf("%s\n", gl_gsa[i]);								// gl_gsa
		printf("[GST      ] ");									// gst
		for(i = 0; i < 9; i++) printf("%s,", gst[i]);						// gst
		printf("%s\n", gst[i]);									// gst
		printf("[GSV      ] ");									// gp_gsv
		for(i = 0; i < 20; i++) printf("%s,", gp_gsv[0][i]);					// gp_gsv
		printf("%s\n", gp_gsv[0][i]);								// gp_gsv
		printf("            ");									// gp_gsv
		for(i = 0; i < 20; i++) printf("%s,", gp_gsv[1][i]);					// gp_gsv
		printf("%s\n", gp_gsv[1][i]);								// gp_gsv
		printf("            ");									// gp_gsv
		for(i = 0; i < 20; i++) printf("%s,", gp_gsv[2][i]);					// gp_gsv
		printf("%s\n", gp_gsv[2][i]);								// gp_gsv
		printf("            ");									// gl_gsv
		for(i = 0; i < 20; i++) printf("%s,", gl_gsv[0][i]);					// gl_gsv
		printf("%s\n", gl_gsv[0][i]);								// gl_gsv
		printf("            ");									// gl_gsv
		for(i = 0; i < 20; i++) printf("%s,", gl_gsv[1][i]);					// gl_gsv
		printf("%s\n", gl_gsv[1][i]);								// gl_gsv
		printf("            ");									// gl_gsv
		for(i = 0; i < 20; i++) printf("%s,", gl_gsv[2][i]);					// gl_gsv
		printf("%s\n", gl_gsv[2][i]);								// gl_gsv
		printf("[HDT      ] ");									// hdt
		for(i = 0; i < 3; i++) printf("%s,", hdt[i]);						// hdt
		printf("%s\n", hdt[i]);									// hdt
		printf("[RMC      ] ");									// rmc
		for(i = 0; i < 13; i++) printf("%s,", rmc[i]);						// rmc
		printf("%s\n", rmc[i]);									// rmc
		printf("[VTG      ] ");									// vtg
		for(i = 0; i < 10; i++) printf("%s,", vtg[i]);						// vtg
		printf("%s\n", vtg[i]);									// vtg
		printf("[ZDA      ] ");									// zda
		for(i = 0; i < 7; i++) printf("%s,", zda[i]);						// zda
		printf("%s\n\n", zda[i]);								// zda
		fflush(stdout);										// バッファフラッシュ [printf表示用]

		#endif											// デバッグ表示終了

		//-------------------------------------------------------------------------------//


		//-- [データ出力] ---------------------------------------------------------------//

		m_Jgd2000PositionOut.write();								// データ出力 [Jgd2000Position]
		m_GpsDataOut.write();									// データ出力 [GpsData]

		//-------------------------------------------------------------------------------//


		//-- [GUI関連] ------------------------------------------------------------------//

		if(gui_flag == 1){									// GUI機能ON


			//-- [データ格納] -------------------------------------------------------//

			sprintf(send_data, "%lf,%lf,%lf",
				send_value[0], send_value[1], send_value[2]);				// データ格納

			//-----------------------------------------------------------------------//


			//-- [データ送信] -------------------------------------------------------//

			if(sendto(send_sock, send_data, strlen(send_data), 0,
				(struct sockaddr *)&send_addr, sizeof(send_addr)) < 0){			// データ送信

				printf("send error!!\n");						// メッセージ表示
				fflush(stdout);								// バッファフラッシュ [printf表示用]

				return RTC::RTC_ERROR;							// 戻り値 [異常終了]

			}

			//-----------------------------------------------------------------------//


		}

		//-------------------------------------------------------------------------------//


	}

	//---------------------------------------------------------------------------------------//


	//-- [GUI関連] --------------------------------------------------------------------------//

	if(gui_flag == 1){										// GUI機能ON


		//-- [データ受信] ---------------------------------------------------------------//

		if(wait_flag == 0){

			// データ受信
			recv_len = recvfrom(recv_sock, recv_data, sizeof(recv_data), 0,
				(struct sockaddr *)&recv_addr, &addr_size);				// データ受信

			if(recv_len < 0){								// 受信チェック

				printf("receive error!!\n");						// メッセージ表示
				fflush(stdout);								// バッファフラッシュ [printf表示用]

				return RTC::RTC_ERROR;							// 戻り値 [異常終了]

			}


			//-- [デバッグrecv] -----------------------------------------------------//

			#ifndef DEBUG_RECV								// デバッグ表示開始

			printf("\n[recv]\n");								// label
			printf("time      = %lf\n", gettimeofday_sec());				// time
			printf("recv data = %s\n\n", recv_data);					// recv_data
			fflush(stdout);									// バッファフラッシュ [printf表示用]

			#endif										// デバッグ表示終了

			//-----------------------------------------------------------------------//


			memset(recv_data, 0, sizeof(recv_data));					// バッファクリア

			wait_flag = 1;									// フラグセット

		}

		//-------------------------------------------------------------------------------//


	}

	//---------------------------------------------------------------------------------------//


	return RTC::RTC_OK;										// 戻り値 [正常終了]

}


/*
RTC::ReturnCode_t GpsInformationProcessing::onAborting(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t GpsInformationProcessing::onError(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t GpsInformationProcessing::onReset(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t GpsInformationProcessing::onStateUpdate(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t GpsInformationProcessing::onRateChanged(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/



extern "C"
{

  void GpsInformationProcessingInit(RTC::Manager* manager)
  {
    RTC::Properties profile(gpsinformationprocessing_spec);
    manager->registerFactory(profile,
                             RTC::Create<GpsInformationProcessing>,
                             RTC::Delete<GpsInformationProcessing>);
  }

};


